==> scpdb-4.12.0.tgz: package/app/tasks/page-import.ts <==
import { WikidotPage } from '../models';
import { log, reportError } from '../core/utils';
import {
  wk, SITES, WKPage, WikidotKit,
} from '../components/wikidot-kit';

import Bluebird = require('bluebird');

const PAGE_NAME_BLACKLIST = /^(admin|nav|css|system):/;

export default function run(wikiName: string, pageName: string): Bluebird<void> {
  if (!(wikiName && pageName)) {
    throw new Error('Wiki name & page name are required');
  }

  log(`Importing page ${wikiName}/${pageName}`);
  const wikiUrl = SITES[wikiName].url;

  if (PAGE_NAME_BLACKLIST.test(pageName)) {
    return Bluebird.resolve();
  }

  return wk.fetchPage(wikiName, pageName)
    .catch((error: Error) => {
      reportError(error, { message: 'Error importing page', extra: { wikiName, pageName } });
    })
    .then((data: WKPage) => WikidotPage.upsert({
      wikiName,
      name: pageName,
      title: data.title,
      content: data.content,
      tags: data.tags,
      rating: data.rating,
      html: data.html,
      createdAt: data.created_at,
      createdBy: data.created_by,
      updatedAt: data.updated_at,
      updatedBy: data.updated_by,
    }))
    .then(() => WikidotKit.fetchPageVotes(wikiUrl, pageName))
    .then((votes) => {
      log(`Imported votes for ${wikiName}/${pageName}`, { extra: votes });
      return WikidotPage.upsert({
        wikiName,
        name: pageName,
        votes: JSON.stringify(votes),
      });
    })
    .then(() => {
      log(`[DONE] ${wikiName}/${pageName}`);
    })
    .catch((error) => {
      reportError(error, { message: 'Error saving page', extra: { wikiName, pageName } });
    });
}

==> scpdb-4.15.1.tgz: package/app/tasks/page-import.ts <==
import { WKPage } from 'wikidot-kit';
import { WikidotPage } from '../models';
import { log, reportError } from '../core/utils';
import { wk, SITES } from '../components/wikidot-kit';

const PAGE_NAME_BLACKLIST = /^(admin|nav|css|system):/;

export default function run(wikiName: string, pageName: string): Promise<void> {
  if (!(wikiName && pageName)) {
    throw new Error('Wiki name & page name are required');
  }

  log(`Importing page ${wikiName}/${pageName}`);
  const wikiUrl = SITES[wikiName].url;

  if (PAGE_NAME_BLACKLIST.test(pageName)) {
    return Promise.resolve();
  }

  return wk.fetchPage(wikiName, pageName)
    .catch((error: Error) => {
      reportError(error, { message: 'Error importing page', extra: { wikiName, pageName } });
    })
    .then((data: WKPage) => WikidotPage.upsert({
      wikiName,
      name: pageName,
      title: data.title,
      content: data.content,
      tags: data.tags,
      rating: data.rating,
      html: data.html,
      createdAt: data.created_at,
      createdBy: data.created_by,
      updatedAt: data.updated_at,
      updatedBy: data.updated_by,
    }))
    .then(() => wk.fetchPageVotes(wikiUrl, pageName))
    .then((votes) => {
      log(`Imported votes for ${wikiName}/${pageName}`, { extra: votes });
      return WikidotPage.upsert({
        wikiName,
        name: pageName,
        votes: JSON.stringify(votes),
      });
    })
    .then(() => {
      log(`[DONE] ${wikiName}/${pageName}`);
    })
    .catch((error) => {
      reportError(error, { message: 'Error saving page', extra: { wikiName, pageName } });
    });
}
